ImageD11 package
================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   ImageD11.silxGui
   ImageD11.tkGui

Submodules
----------

ImageD11.ImageD11\_file\_series module
--------------------------------------

.. automodule:: ImageD11.ImageD11_file_series
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.ImageD11\_thread module
--------------------------------

.. automodule:: ImageD11.ImageD11_thread
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.ImageD11options module
-------------------------------

.. automodule:: ImageD11.ImageD11options
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.blobcorrector module
-----------------------------

.. automodule:: ImageD11.blobcorrector
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.cImageD11 module
-------------------------

.. automodule:: ImageD11.cImageD11
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.cImageD11\_docstrings module
-------------------------------------

.. automodule:: ImageD11.cImageD11_docstrings
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.columnfile module
--------------------------

.. automodule:: ImageD11.columnfile
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.compute\_fazit module
------------------------------

.. automodule:: ImageD11.compute_fazit
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.correct module
-----------------------

.. automodule:: ImageD11.correct
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.eps\_sig\_solver module
--------------------------------

.. automodule:: ImageD11.eps_sig_solver
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.fft\_index\_refac module
---------------------------------

.. automodule:: ImageD11.fft_index_refac
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.finite\_strain module
------------------------------

.. automodule:: ImageD11.finite_strain
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.grain module
---------------------

.. automodule:: ImageD11.grain
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.grid\_index\_parallel module
-------------------------------------

.. automodule:: ImageD11.grid_index_parallel
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.guicommand module
--------------------------

.. automodule:: ImageD11.guicommand
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.gv\_general module
---------------------------

.. automodule:: ImageD11.gv_general
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.indexer module
-----------------------

.. automodule:: ImageD11.indexer
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.indexing module
------------------------

.. automodule:: ImageD11.indexing
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.labelimage module
--------------------------

.. automodule:: ImageD11.labelimage
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.lattice\_reduction module
----------------------------------

.. automodule:: ImageD11.lattice_reduction
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.license module
-----------------------

.. automodule:: ImageD11.license
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.parameters module
--------------------------

.. automodule:: ImageD11.parameters
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.peakmerge module
-------------------------

.. automodule:: ImageD11.peakmerge
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.peaksearcher module
----------------------------

.. automodule:: ImageD11.peaksearcher
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.rc\_array module
-------------------------

.. automodule:: ImageD11.rc_array
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.refinegrains module
----------------------------

.. automodule:: ImageD11.refinegrains
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.rotdex module
----------------------

.. automodule:: ImageD11.rotdex
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.rsv module
-------------------

.. automodule:: ImageD11.rsv
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.rsv\_mapper module
---------------------------

.. automodule:: ImageD11.rsv_mapper
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.saintraw module
------------------------

.. automodule:: ImageD11.saintraw
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.scale module
---------------------

.. automodule:: ImageD11.scale
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.simplex module
-----------------------

.. automodule:: ImageD11.simplex
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.sparseframe module
---------------------------

.. automodule:: ImageD11.sparseframe
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.sym\_u module
----------------------

.. automodule:: ImageD11.sym_u
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.symops module
----------------------

.. automodule:: ImageD11.symops
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.threshold\_image module
--------------------------------

.. automodule:: ImageD11.threshold_image
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.transform module
-------------------------

.. automodule:: ImageD11.transform
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.transformer module
---------------------------

.. automodule:: ImageD11.transformer
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.unitcell module
------------------------

.. automodule:: ImageD11.unitcell
   :members:
   :undoc-members:
   :show-inheritance:

ImageD11.write\_graindex\_gv module
-----------------------------------

.. automodule:: ImageD11.write_graindex_gv
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: ImageD11
   :members:
   :undoc-members:
   :show-inheritance:
